@@ -1,5 +1,4 @@
-"""pytest for the table.py file. Covers the PyTable and PyTables classes.
-"""
+"""pytest for the table.py file. Covers the PyTable and PyTables classes."""
 from test.config import testing_parameters
 import pytest
 from pytabular import Tabular
@@ -7,6 +6,7 @@ from pytabular import Tabular
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_model(model):
+    """Tests successful `__rich_repr()` `on Tabular()` class."""
     try:
         model.__rich_repr__()
     except Exception:
@@ -15,6 +15,7 @@ def test_rich_repr_model(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_table(model):
+    """Tests successful `__rich_repr()` `on PyTable()` class."""
     try:
         model.Tables[0].__rich_repr__()
     except Exception:
@@ -23,6 +24,7 @@ def test_rich_repr_table(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_tables(model):
+    """Tests successful `__rich_repr()` `on PyTables()` class."""
     try:
         model.Tables.__rich_repr__()
     except Exception:
@@ -31,6 +33,7 @@ def test_rich_repr_tables(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_column(model):
+    """Tests successful `__rich_repr()` `on PyColumn()` class."""
     try:
         model.Columns[0].__rich_repr__()
     except Exception:
@@ -39,6 +42,7 @@ def test_rich_repr_column(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_columns(model):
+    """Tests successful `__rich_repr()` `on PyColumns()` class."""
     try:
         model.Columns.__rich_repr__()
     except Exception:
@@ -47,6 +51,7 @@ def test_rich_repr_columns(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_partition(model):
+    """Tests successful `__rich_repr()` `on PyPartition()` class."""
     try:
         model.Partitions[0].__rich_repr__()
     except Exception:
@@ -55,6 +60,7 @@ def test_rich_repr_partition(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_partitions(model):
+    """Tests successful `__rich_repr()` `on PyPartitions()` class."""
     try:
         model.Partitions.__rich_repr__()
     except Exception:
@@ -63,6 +69,7 @@ def test_rich_repr_partitions(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_measure(model):
+    """Tests successful `__rich_repr()` `on PyMeasure()` class."""
     try:
         model.Measures[0].__rich_repr__()
     except Exception:
@@ -71,20 +78,22 @@ def test_rich_repr_measure(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_rich_repr_measures(model):
+    """Tests successful `__rich_repr()` `on PyMeasures()` class."""
     try:
         model.Measures.__rich_repr__()
     except Exception:
         pytest.fail("__rich_repr__() failed")
 
 
-# TODO need to get this to have coverage for full getattr
 @pytest.mark.parametrize("model", testing_parameters)
 def test_get_attr(model):
+    """Tests custom get attribute from `PyObject` class."""
     assert isinstance(model.Tables[0].Model, Tabular)
 
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_iadd_tables(model):
+    """Tests `__iadd__()` with `PyTables()`."""
     a = model.Tables.find("Sales")
     b = model.Tables.find("Date")
     a += b
@@ -93,6 +102,7 @@ def test_iadd_tables(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_iadd_table(model):
+    """Tests `__iadd__()` with a `PyTable()`."""
     a = model.Tables.find("Sales")
     b = model.Tables.find("Date")[0]
     a += b
